==> mdm-rpc-0.1.17-sources.jar: com/chinayanghe/msp/mdm/vo/terminal/TmTerminalVo.java <==
package com.chinayanghe.msp.mdm.vo.terminal;

import com.chinayanghe.msp.mdm.constant.NotNull;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/** 
 * 终端基础信息dto
 * @author shu
 * @version v1.0
 */
public class TmTerminalVo implements Serializable {

	private static final long serialVersionUID = -4929248973526645453L;
	private String id;
	/**
	 * 终端编码
	 */
	@NotNull
	private String terminalCode;
	/**
	 * ERP编码
	 */
	/*private String erpCode;*/
	/**
	 * 终端名称
	 */
	@NotNull
	private String terminalName;
	/**
	 * 终端类型
	 * 01：核心  02：非核心
	 */
	@NotNull
	private String terminalType;
	/**
	 * 渠道类型
	 */
	@NotNull
	private String channelType;
	
	/**
	 * 合作状态
	 */
	/*private String cooperative;*/
	/**
	 * 省
	 */
	@NotNull
	private String province;
	/**
	 * 市
	 */
	@NotNull
	private String city;
	/**
	 * 区
	 */
	@NotNull
	private String area;
	/**
	 * 乡镇编码
	 */
	@NotNull
	private String towns;
	/**
	 * 终端地址
	 */
	@NotNull
	private String address;
	/**
	 * 终端联系人
	 */
	private List<TerminalLinkManVo> terminalLinkManVos;
	/**
     * 数据审批状态
	 */
	private String auditStatus;
	/**
	 * 启用状态：0-启用
	 */
	private Integer enableStatus;
	/**
	 * 创建时间
	 */
	@NotNull
	private Date createDate;
	/**
	 * 创建用户账号
	 */
	@NotNull
	private String createName;
	/**
	 * 修改时间
	 */
	@NotNull
	private Date updateDate;
	/**
	 * 修改用户账号
	 */
	@NotNull
	private String updateName;

	/**
     * 经度
	 */
	@NotNull
	private String longitude;
	/**
     * 纬度
	 */
	@NotNull
	private String latitude;

	/**
	 * 附近终端距离
	 */
	private Double distance;

	/** 创建岗位*/
	@NotNull
	private String positionCode;
	/** 更新岗位*/
	@NotNull
	private String positionCodeUp;

	/**
	 * 营业执照编码
	 * 字符类型（length=100）-扩展字段1
	 */
	@NotNull
	private String extChar1;
	/**
	 * 营业执照照片
	 * 字符类型（length=100）-扩展字段2
	 */
	@NotNull
	private String extChar2;
	/**
	 * 门头照片
	 * 字符类型（length=100）-扩展字段3
	 */
	@NotNull
	private String extChar3;
	/**
	 * 终端来源编码
	 * 01：系统导入    02：业务员录入    03：终端自主注册
	 * 字符类型（length=100）-扩展字段4
	 */
	@NotNull
	private String extChar4;
	/**
	 * 拜访状态编码
	 * 01：存在拜访记录    02：从未拜访
	 * 字符类型（length=100）-扩展字段5
	 */
	@NotNull
	private String extChar5;
	/**
	 * 督查状态编码
	 * 01：已督查   02：从未督查
	 * 字符类型（length=200）-扩展字段6
	 */
	@NotNull
	private String extChar6;
	/**
	 * 开户银行
	 * 字符类型（length=200）-扩展字段7
	 */
	@NotNull
	private String extChar7;
	/**
	 * 银行开户名
	 * 字符类型（length=200）-扩展字段8
	 */
	@NotNull
	private String extChar8;
	/**
	 * 银行账号
	 * 字符类型（length=200）-扩展字段9
	 */
	@NotNull
	private String extChar9;
	/**
	 * 身份证号
	 * 字符类型（length=200）-扩展字段10
	 */
	@NotNull
	private String extChar10;
	/**
	 * qq号
	 * 字符类型（length=1000）-扩展字段11
	 */
	private String extChar11;
	/**
	 * 微信号
	 * 字符类型（length=1000）-扩展字段12
	 */
	private String extChar12;
	/**
	 * 字符类型（length=1000）-扩展字段13
	 * 备注
	 */
	@NotNull
	private String extChar13;
	/**
	 * 字符类型（length=1000）-扩展字段14
	 * 启停原因
	 */
	private String extChar14;
	/**
	 * 字符类型（length=1000）-扩展字段15
	 * 省名
	 */
	private String extChar15;
	/**
	 * 字符类型（length=500）-扩展字段16
	 * 市名
	 */
	private String extChar16;
	/**
	 * 字符类型（length=500）-扩展字段17
	 * 区名
	 */
	private String extChar17;
	/**
	 * 字符类型（length=500）-扩展字段18
	 */
	private String extChar18;
	/**
	 * 字符类型（length=500）-扩展字段19
	 */
	private String extChar19;
	/**
	 * 字符类型（length=500）-扩展字段20
	 */
	private String extChar20;
	/**
	 * 字符类型（length=500）-扩展字段21
	 */
	private String extChar21;
	/**
	 * 字符类型（length=500）-扩展字段22
	 */
	private String extChar22;
	/**
	 * 字符类型（length=500）-扩展字段23
	 */
	private String extChar23;
	/**
	 * 字符类型（length=500）-扩展字段24
	 */
	private String extChar24;
	/**
	 * 字符类型（length=500）-扩展字段25
	 */
	private String extChar25;
	/**
	 * 字符类型（length=500）-扩展字段26
	 */
	private String extChar26;
	/**
	 * 字符类型（length=500）-扩展字段27
	 */
	private String extChar27;
	/**
	 * 字符类型（length=500）-扩展字段28
	 */
	private String extChar28;
	/**
	 * 字符类型（length=500）-扩展字段29
	 * 关键联系人
	 */
	private String extChar29;
	/**
	 * 字符类型（length=500）-扩展字段30
	 * 关键联系方式
	 */
	private String extChar30;
	/**
	 * 数字类型-扩展字段1
	 */
	private Integer extNumber1;
	/**
	 * 数字类型-扩展字段2
	 */
	private Integer extNumber2;
	/**
	 * 数字类型-扩展字段3
	 */
	private Integer extNumber3;
	/**
	 * 数字类型-扩展字段4
	 */
	private Integer extNumber4;
	/**
	 * 数字类型-扩展字段5
	 */
	private Integer extNumber5;

	/**
	 * 最近拜访时间
	 */
	private Date lastVisitTime;

	public String getTerminalCode() {
		return terminalCode;
	}

	public void setTerminalCode(String terminalCode) {
		this.terminalCode = terminalCode;
	}

	/*public String getErpCode() {
		return erpCode;
	}

	public void setErpCode(String erpCode) {
		this.erpCode = erpCode;
	}*/

	public String getTerminalName() {
		return terminalName;
	}

	public void setTerminalName(String terminalName) {
		this.terminalName = terminalName;
	}

	public String getTerminalType() {
		return terminalType;
	}

	public void setTerminalType(String terminalType) {
		this.terminalType = terminalType;
	}

	public String getChannelType() {
		return channelType;
	}

	public void setChannelType(String channelType) {
		this.channelType = channelType;
	}

	/*public String getCooperative() {
		return cooperative;
	}

	public void setCooperative(String cooperative) {
		this.cooperative = cooperative;
	}*/

	public String getProvince() {
		return province;
	}

	public void setProvince(String province) {
		this.province = province;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getArea() {
		return area;
	}

	public void setArea(String area) {
		this.area = area;
	}

	public String getAddress() {
		return address;
	}

	public void setAddress(String address) {
		this.address = address;
	}

	public List<TerminalLinkManVo> getTerminalLinkManVos() {
		return terminalLinkManVos;
	}

	public void setTerminalLinkManVos(List<TerminalLinkManVo> terminalLinkManVos) {
		this.terminalLinkManVos = terminalLinkManVos;
	}

	public Integer getEnableStatus() {
		return enableStatus;
	}

	public void setEnableStatus(Integer enableStatus) {
		this.enableStatus = enableStatus;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public String getCreateName() {
		return createName;
	}

	public void setCreateName(String createName) {
		this.createName = createName;
	}

	public Date getUpdateDate() {
		return updateDate;
	}

	public void setUpdateDate(Date updateDate) {
		this.updateDate = updateDate;
	}

	public String getUpdateName() {
		return updateName;
	}

	public void setUpdateName(String updateName) {
		this.updateName = updateName;
	}

	public String getLongitude() {
		return longitude;
	}

	public void setLongitude(String longitude) {
		this.longitude = longitude;
	}

	public String getLatitude() {
		return latitude;
	}

	public void setLatitude(String latitude) {
		this.latitude = latitude;
	}

	public String getPositionCode() {
		return positionCode;
	}

	public void setPositionCode(String positionCode) {
		this.positionCode = positionCode;
	}

	public String getPositionCodeUp() {
		return positionCodeUp;
	}

	public void setPositionCodeUp(String positionCodeUp) {
		this.positionCodeUp = positionCodeUp;
	}

	public String getExtChar1() {
		return extChar1;
	}

	public void setExtChar1(String extChar1) {
		this.extChar1 = extChar1;
	}

	public String getExtChar2() {
		return extChar2;
	}

	public void setExtChar2(String extChar2) {
		this.extChar2 = extChar2;
	}

	public String getExtChar3() {
		return extChar3;
	}

	public void setExtChar3(String extChar3) {
		this.extChar3 = extChar3;
	}

	public String getExtChar4() {
		return extChar4;
	}

	public void setExtChar4(String extChar4) {
		this.extChar4 = extChar4;
	}

	public String getExtChar5() {
		return extChar5;
	}

	public void setExtChar5(String extChar5) {
		this.extChar5 = extChar5;
	}

	public String getExtChar6() {
		return extChar6;
	}

	public void setExtChar6(String extChar6) {
		this.extChar6 = extChar6;
	}

	public String getExtChar7() {
		return extChar7;
	}

	public void setExtChar7(String extChar7) {
		this.extChar7 = extChar7;
	}

	public String getExtChar8() {
		return extChar8;
	}

	public void setExtChar8(String extChar8) {
		this.extChar8 = extChar8;
	}

	public String getExtChar9() {
		return extChar9;
	}

	public void setExtChar9(String extChar9) {
		this.extChar9 = extChar9;
	}

	public String getExtChar10() {
		return extChar10;
	}

	public void setExtChar10(String extChar10) {
		this.extChar10 = extChar10;
	}

	public String getExtChar11() {
		return extChar11;
	}

	public void setExtChar11(String extChar11) {
		this.extChar11 = extChar11;
	}

	public String getExtChar12() {
		return extChar12;
	}

	public void setExtChar12(String extChar12) {
		this.extChar12 = extChar12;
	}

	public String getExtChar13() {
		return extChar13;
	}

	public void setExtChar13(String extChar13) {
		this.extChar13 = extChar13;
	}

	public String getExtChar14() {
		return extChar14;
	}

	public void setExtChar14(String extChar14) {
		this.extChar14 = extChar14;
	}

	public String getExtChar15() {
		return extChar15;
	}

	public void setExtChar15(String extChar15) {
		this.extChar15 = extChar15;
	}

	public String getExtChar16() {
		return extChar16;
	}

	public void setExtChar16(String extChar16) {
		this.extChar16 = extChar16;
	}

	public String getExtChar17() {
		return extChar17;
	}

	public void setExtChar17(String extChar17) {
		this.extChar17 = extChar17;
	}

	public String getExtChar18() {
		return extChar18;
	}

	public void setExtChar18(String extChar18) {
		this.extChar18 = extChar18;
	}

	public String getExtChar19() {
		return extChar19;
	}

	public void setExtChar19(String extChar19) {
		this.extChar19 = extChar19;
	}

	public String getExtChar20() {
		return extChar20;
	}

	public void setExtChar20(String extChar20) {
		this.extChar20 = extChar20;
	}

	public String getExtChar21() {
		return extChar21;
	}

	public void setExtChar21(String extChar21) {
		this.extChar21 = extChar21;
	}

	public String getExtChar22() {
		return extChar22;
	}

	public void setExtChar22(String extChar22) {
		this.extChar22 = extChar22;
	}

	public String getExtChar23() {
		return extChar23;
	}

	public void setExtChar23(String extChar23) {
		this.extChar23 = extChar23;
	}

	public String getExtChar24() {
		return extChar24;
	}

	public void setExtChar24(String extChar24) {
		this.extChar24 = extChar24;
	}

	public String getExtChar25() {
		return extChar25;
	}

	public void setExtChar25(String extChar25) {
		this.extChar25 = extChar25;
	}

	public String getExtChar26() {
		return extChar26;
	}

	public void setExtChar26(String extChar26) {
		this.extChar26 = extChar26;
	}

	public String getExtChar27() {
		return extChar27;
	}

	public void setExtChar27(String extChar27) {
		this.extChar27 = extChar27;
	}

	public String getExtChar28() {
		return extChar28;
	}

	public void setExtChar28(String extChar28) {
		this.extChar28 = extChar28;
	}

	public String getExtChar29() {
		return extChar29;
	}

	public void setExtChar29(String extChar29) {
		this.extChar29 = extChar29;
	}

	public String getExtChar30() {
		return extChar30;
	}

	public void setExtChar30(String extChar30) {
		this.extChar30 = extChar30;
	}

	public Integer getExtNumber1() {
		return extNumber1;
	}

	public void setExtNumber1(Integer extNumber1) {
		this.extNumber1 = extNumber1;
	}

	public Integer getExtNumber2() {
		return extNumber2;
	}

	public void setExtNumber2(Integer extNumber2) {
		this.extNumber2 = extNumber2;
	}

	public Integer getExtNumber3() {
		return extNumber3;
	}

	public void setExtNumber3(Integer extNumber3) {
		this.extNumber3 = extNumber3;
	}

	public Integer getExtNumber4() {
		return extNumber4;
	}

	public void setExtNumber4(Integer extNumber4) {
		this.extNumber4 = extNumber4;
	}

	public Integer getExtNumber5() {
		return extNumber5;
	}

	public void setExtNumber5(Integer extNumber5) {
		this.extNumber5 = extNumber5;
	}

	public Date getLastVisitTime() {
		return lastVisitTime;
	}

	public void setLastVisitTime(Date lastVisitTime) {
		this.lastVisitTime = lastVisitTime;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getTowns() {
		return towns;
	}

	public void setTowns(String towns) {
		this.towns = towns;
	}

	public String getAuditStatus() {
		return auditStatus;
	}

	public void setAuditStatus(String auditStatus) {
		this.auditStatus = auditStatus;
	}

	public Double getDistance() {
		return distance;
	}

	public void setDistance(Double distance) {
		this.distance = distance;
	}
}

==> mdm-rpc-0.1.85-sources.jar: com/chinayanghe/msp/mdm/vo/terminal/TmTerminalVo.java <==
package com.chinayanghe.msp.mdm.vo.terminal;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/** 
 * 终端基础信息vo（包含终端的所有信息（联系人，岗位））
 * @author shu
 * @version v1.0
 */
public class TmTerminalVo implements Serializable {

	private static final long serialVersionUID = 1L;

	private String id;

	/** 数据版本*/
	private Integer version;
	/** 审批类型（新增，修改，启，停）SfaProcessType*/
	private Integer auditType;
	/**
	 * 终端编码
	 */
	private String terminalCode;
	/**
	 * 终端名称
	 */
	private String terminalName;
	/**
	 * 终端类型
	 */
	private String terminalType;
	/**
	 * 渠道类型
	 */
	private String channelType;
	/**
	 * 省编码
	 */
	private String province;
	/**
	 * 市编码
	 */
	private String city;
	/**
	 * 区编码
	 */
	private String area;
	/**
	 * 乡镇编码
	 */
	private String towns;
	/**
	 * 终端地址
	 */
	private String address;
	/**
	 * 终端联系人
	 */
	private List<TerminalLinkManVo> terminalLinkManVos;
	/**
	 * 终端岗位关联对象
	 */
	private List<TmRTermCustPosBGVo> termPoss;
	/**
     * 数据审批状态
	 */
	private String auditStatus;
	/**
	 * 启用状态：0-启用
	 */
	private Integer enableStatus;
	/**
	 * 创建时间
	 */
	private Date createDate;
	/**
	 * 创建用户账号
	 */
	private String createName;
	/**
	 * 修改时间
	 */

	private Date updateDate;
	/**
	 * 修改用户账号
	 */
	private String updateName;

	/**
     * 经度
	 */
	private String longitude;
	/**
     * 纬度
	 */
	private String latitude;

	/** 创建岗位*/
	private String positionCode;
	/** 更新岗位*/
	private String positionCodeUp;

	/**
	 * 营业执照编码
	 * 字符类型（length=100）-扩展字段1
	 */
	private String extChar1;
	/**
	 * 营业执照照片
	 * 字符类型（length=100）-扩展字段2
	 */
	private String extChar2;
	/**
	 * 门头照片（逗号分隔有多张）
	 * 字符类型（length=100）-扩展字段3
	 */
	private String extChar3;
	/**
	 * 终端来源编码
	 * 01：系统导入    02：业务员录入    03：终端自主注册
	 * 字符类型（length=100）-扩展字段4
	 */
	private String extChar4;
	/**
	 * 拜访状态编码
	 * 01：存在拜访记录    02：从未拜访
	 * 字符类型（length=100）-扩展字段5
	 */
	private String extChar5;
	/**
	 * 督查状态编码
	 * 01：已督查   02：从未督查
	 * 字符类型（length=200）-扩展字段6
	 */
	private String extChar6;
	/**
	 * 开户银行
	 * 字符类型（length=200）-扩展字段7
	 */
	private String extChar7;
	/**
	 * 银行开户名
	 * 字符类型（length=200）-扩展字段8
	 */
	private String extChar8;
	/**
	 * 银行账号
	 * 字符类型（length=200）-扩展字段9
	 */
	private String extChar9;
	/**
	 * 身份证号
	 * 字符类型（length=200）-扩展字段10
	 */
	private String extChar10;
	/**
	 * qq号
	 * 字符类型（length=1000）-扩展字段11
	 */
	private String extChar11;
	/**
	 * 微信号
	 * 字符类型（length=1000）-扩展字段12
	 */
	private String extChar12;
	/**
	 * 字符类型（length=1000）-扩展字段13
	 * 备注
	 */
	private String extChar13;
	/**
	 * 字符类型（length=1000）-扩展字段14
	 * 启停原因
	 */
	private String extChar14;
	/**
	 * 字符类型（length=1000）-扩展字段15
	 */
	private String extChar15;
	/**
	 * 字符类型（length=500）-扩展字段16
	 */
	private String extChar16;
	/**
	 * 字符类型（length=500）-扩展字段17
	 */
	private String extChar17;
	/**
	 * 字符类型（length=500）-扩展字段18
	 */
	private String extChar18;
	/**
	 * 字符类型（length=500）-扩展字段19
	 */
	private String extChar19;
	/**
	 * 字符类型（length=500）-扩展字段20
	 */
	private String extChar20;
	/**
	 * 字符类型（length=500）-扩展字段21
	 */
	private String extChar21;
	/**
	 * 字符类型（length=500）-扩展字段22
	 */
	private String extChar22;
	/**
	 * 字符类型（length=500）-扩展字段23
	 */
	private String extChar23;
	/**
	 * 字符类型（length=500）-扩展字段24
	 */
	private String extChar24;
	/**
	 * 字符类型（length=500）-扩展字段25
	 */
	private String extChar25;
	/**
	 * 字符类型（length=500）-扩展字段26
	 */
	private String extChar26;
	/**
	 * 字符类型（length=500）-扩展字段27
	 */
	private String extChar27;
	/**
	 * 字符类型（length=500）-扩展字段28
	 */
	private String extChar28;
	/**
	 * 字符类型（length=500）-扩展字段29
	 */
	private String extChar29;
	/**
	 * 字符类型（length=500）-扩展字段30
	 */
	private String extChar30;
	/**
	 * 数字类型-扩展字段1
	 */
	/** 是否为专卖店 1是 0不是*/
	private Integer extNumber1;
	/**
	 * 数字类型-扩展字段2
	 */
	private Integer extNumber2;
	/**
	 * 数字类型-扩展字段3
	 */
	private Integer extNumber3;
	/**
	 * 数字类型-扩展字段4
	 */
	private Integer extNumber4;
	/**
	 * 数字类型-扩展字段5
	 */
	private Integer extNumber5;

	/**
	 * 最近拜访时间
	 */
	private Date lastVisitTime;

	public String getTerminalCode() {
		return terminalCode;
	}

	public void setTerminalCode(String terminalCode) {
		this.terminalCode = terminalCode;
	}

	public String getTerminalName() {
		return terminalName;
	}

	public void setTerminalName(String terminalName) {
		this.terminalName = terminalName;
	}

	public String getTerminalType() {
		return terminalType;
	}

	public void setTerminalType(String terminalType) {
		this.terminalType = terminalType;
	}

	public String getChannelType() {
		return channelType;
	}

	public void setChannelType(String channelType) {
		this.channelType = channelType;
	}

	public String getProvince() {
		return province;
	}

	public void setProvince(String province) {
		this.province = province;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getArea() {
		return area;
	}

	public void setArea(String area) {
		this.area = area;
	}

	public String getAddress() {
		return address;
	}

	public void setAddress(String address) {
		this.address = address;
	}

	public Integer getEnableStatus() {
		return enableStatus;
	}

	public void setEnableStatus(Integer enableStatus) {
		this.enableStatus = enableStatus;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public String getCreateName() {
		return createName;
	}

	public void setCreateName(String createName) {
		this.createName = createName;
	}

	public Date getUpdateDate() {
		return updateDate;
	}

	public void setUpdateDate(Date updateDate) {
		this.updateDate = updateDate;
	}

	public String getUpdateName() {
		return updateName;
	}

	public void setUpdateName(String updateName) {
		this.updateName = updateName;
	}

	public String getLongitude() {
		return longitude;
	}

	public void setLongitude(String longitude) {
		this.longitude = longitude;
	}

	public String getLatitude() {
		return latitude;
	}

	public void setLatitude(String latitude) {
		this.latitude = latitude;
	}

	public String getPositionCode() {
		return positionCode;
	}

	public void setPositionCode(String positionCode) {
		this.positionCode = positionCode;
	}

	public String getPositionCodeUp() {
		return positionCodeUp;
	}

	public void setPositionCodeUp(String positionCodeUp) {
		this.positionCodeUp = positionCodeUp;
	}

	public String getExtChar1() {
		return extChar1;
	}

	public void setExtChar1(String extChar1) {
		this.extChar1 = extChar1;
	}

	public String getExtChar2() {
		return extChar2;
	}

	public void setExtChar2(String extChar2) {
		this.extChar2 = extChar2;
	}

	public String getExtChar3() {
		return extChar3;
	}

	public void setExtChar3(String extChar3) {
		this.extChar3 = extChar3;
	}

	public String getExtChar4() {
		return extChar4;
	}

	public void setExtChar4(String extChar4) {
		this.extChar4 = extChar4;
	}

	public String getExtChar5() {
		return extChar5;
	}

	public void setExtChar5(String extChar5) {
		this.extChar5 = extChar5;
	}

	public String getExtChar6() {
		return extChar6;
	}

	public void setExtChar6(String extChar6) {
		this.extChar6 = extChar6;
	}

	public String getExtChar7() {
		return extChar7;
	}

	public void setExtChar7(String extChar7) {
		this.extChar7 = extChar7;
	}

	public String getExtChar8() {
		return extChar8;
	}

	public void setExtChar8(String extChar8) {
		this.extChar8 = extChar8;
	}

	public String getExtChar9() {
		return extChar9;
	}

	public void setExtChar9(String extChar9) {
		this.extChar9 = extChar9;
	}

	public String getExtChar10() {
		return extChar10;
	}

	public void setExtChar10(String extChar10) {
		this.extChar10 = extChar10;
	}

	public String getExtChar11() {
		return extChar11;
	}

	public void setExtChar11(String extChar11) {
		this.extChar11 = extChar11;
	}

	public String getExtChar12() {
		return extChar12;
	}

	public void setExtChar12(String extChar12) {
		this.extChar12 = extChar12;
	}

	public String getExtChar13() {
		return extChar13;
	}

	public void setExtChar13(String extChar13) {
		this.extChar13 = extChar13;
	}

	public String getExtChar14() {
		return extChar14;
	}

	public void setExtChar14(String extChar14) {
		this.extChar14 = extChar14;
	}

	public String getExtChar15() {
		return extChar15;
	}

	public void setExtChar15(String extChar15) {
		this.extChar15 = extChar15;
	}

	public String getExtChar16() {
		return extChar16;
	}

	public void setExtChar16(String extChar16) {
		this.extChar16 = extChar16;
	}

	public String getExtChar17() {
		return extChar17;
	}

	public void setExtChar17(String extChar17) {
		this.extChar17 = extChar17;
	}

	public String getExtChar18() {
		return extChar18;
	}

	public void setExtChar18(String extChar18) {
		this.extChar18 = extChar18;
	}

	public String getExtChar19() {
		return extChar19;
	}

	public void setExtChar19(String extChar19) {
		this.extChar19 = extChar19;
	}

	public String getExtChar20() {
		return extChar20;
	}

	public void setExtChar20(String extChar20) {
		this.extChar20 = extChar20;
	}

	public String getExtChar21() {
		return extChar21;
	}

	public void setExtChar21(String extChar21) {
		this.extChar21 = extChar21;
	}

	public String getExtChar22() {
		return extChar22;
	}

	public void setExtChar22(String extChar22) {
		this.extChar22 = extChar22;
	}

	public String getExtChar23() {
		return extChar23;
	}

	public void setExtChar23(String extChar23) {
		this.extChar23 = extChar23;
	}

	public String getExtChar24() {
		return extChar24;
	}

	public void setExtChar24(String extChar24) {
		this.extChar24 = extChar24;
	}

	public String getExtChar25() {
		return extChar25;
	}

	public void setExtChar25(String extChar25) {
		this.extChar25 = extChar25;
	}

	public String getExtChar26() {
		return extChar26;
	}

	public void setExtChar26(String extChar26) {
		this.extChar26 = extChar26;
	}

	public String getExtChar27() {
		return extChar27;
	}

	public void setExtChar27(String extChar27) {
		this.extChar27 = extChar27;
	}

	public String getExtChar28() {
		return extChar28;
	}

	public void setExtChar28(String extChar28) {
		this.extChar28 = extChar28;
	}

	public String getExtChar29() {
		return extChar29;
	}

	public void setExtChar29(String extChar29) {
		this.extChar29 = extChar29;
	}

	public String getExtChar30() {
		return extChar30;
	}

	public void setExtChar30(String extChar30) {
		this.extChar30 = extChar30;
	}

	public Integer getExtNumber1() {
		return extNumber1;
	}

	public void setExtNumber1(Integer extNumber1) {
		this.extNumber1 = extNumber1;
	}

	public Integer getExtNumber2() {
		return extNumber2;
	}

	public void setExtNumber2(Integer extNumber2) {
		this.extNumber2 = extNumber2;
	}

	public Integer getExtNumber3() {
		return extNumber3;
	}

	public void setExtNumber3(Integer extNumber3) {
		this.extNumber3 = extNumber3;
	}

	public Integer getExtNumber4() {
		return extNumber4;
	}

	public void setExtNumber4(Integer extNumber4) {
		this.extNumber4 = extNumber4;
	}

	public Integer getExtNumber5() {
		return extNumber5;
	}

	public void setExtNumber5(Integer extNumber5) {
		this.extNumber5 = extNumber5;
	}

	public Date getLastVisitTime() {
		return lastVisitTime;
	}

	public void setLastVisitTime(Date lastVisitTime) {
		this.lastVisitTime = lastVisitTime;
	}

	public String getTowns() {
		return towns;
	}

	public void setTowns(String towns) {
		this.towns = towns;
	}

	public String getAuditStatus() {
		return auditStatus;
	}

	public void setAuditStatus(String auditStatus) {
		this.auditStatus = auditStatus;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public Integer getVersion() {
		return version;
	}

	public void setVersion(Integer version) {
		this.version = version;
	}

	public Integer getAuditType() {
		return auditType;
	}

	public void setAuditType(Integer auditType) {
		this.auditType = auditType;
	}

	public List<TerminalLinkManVo> getTerminalLinkManVos() {
		return terminalLinkManVos;
	}

	public void setTerminalLinkManVos(List<TerminalLinkManVo> terminalLinkManVos) {
		this.terminalLinkManVos = terminalLinkManVos;
	}

	public List<TmRTermCustPosBGVo> getTermPoss() {
		return termPoss;
	}

	public void setTermPoss(List<TmRTermCustPosBGVo> termPoss) {
		this.termPoss = termPoss;
	}
}
